@@ -12,6 +12,20 @@ from argus.engine import State
 from argus.callbacks.callback import Callback
 from argus.metrics.metric import init_better
 
+__all__ = [
+    "LRScheduler",
+    "LambdaLR",
+    "StepLR",
+    "MultiStepLR",
+    "ExponentialLR",
+    "CosineAnnealingLR",
+    "ReduceLROnPlateau",
+    "CyclicLR",
+    "CosineAnnealingWarmRestarts",
+    "MultiplicativeLR",
+    "OneCycleLR",
+]
+
 
 class LRScheduler(Callback):
     def __init__(self,
@@ -67,7 +81,7 @@ class LambdaLR(LRScheduler):
 class StepLR(LRScheduler):
     """StepLR scheduler.
 
-    Multiply learning rate by a given factor with a given period.
+    Decays the learning rate of each parameter group by gamma every step_size epochs.
 
     Args:
         step_size (int): Period of learning rate update in epochs.
@@ -95,7 +109,8 @@ class StepLR(LRScheduler):
 class MultiStepLR(LRScheduler):
     """MultiStepLR scheduler.
 
-    Multiply learning rate by a given factor on each epoch from a given list.
+    Decays the learning rate of each parameter group by gamma once the number of epoch
+    reaches one of the milestones.
 
     Args:
         milestones (list of int): List of epochs number to perform lr step.
@@ -121,9 +136,9 @@ class MultiStepLR(LRScheduler):
 
 
 class ExponentialLR(LRScheduler):
-    """MultiStepLR scheduler.
+    """ExponentialLR scheduler.
 
-    Multiply learning rate by a given factor on each epoch.
+    Decays the learning rate of each parameter group by gamma every epoch.
 
     Args:
         gamma (float, optional): Multiplicative factor. Defaults to 0.1.
